from flask import Blueprint, render_template, request, url_for, redirect, flash, current_app

from uffd.navbar import register_navbar
from uffd.csrf import csrf_protect
from uffd.ldap import ldap
from uffd.session import login_required, is_valid_session, get_current_user
from uffd.user.models import Group

from uffd.mail.models import Mail

bp = Blueprint("mail", __name__, template_folder='templates', url_prefix='/mail/')
@bp.before_request
@login_required()
def mail_acl(): #pylint: disable=inconsistent-return-statements
	if not mail_acl_check():
		flash('Access denied')
		return redirect(url_for('index'))

def mail_acl_check():
	return is_valid_session() and get_current_user().is_in_group(current_app.config['ACL_ADMIN_GROUP'])

@bp.route("/")
@register_navbar('Mail', icon='envelope', blueprint=bp, visible=mail_acl_check)
def index():
	return render_template('mail_list.html', mails=Mail.ldap_all())

@bp.route("/<uid>")
@bp.route("/new")
def show(uid=None):
	mail = Mail()
	if uid is not None:
		mail = Mail.ldap_filter_by(uid=uid)[0]
	return render_template('mail.html', mail=mail)

@bp.route("/<uid>/update", methods=['POST'])
@bp.route("/new", methods=['POST'])
@csrf_protect(blueprint=bp)
def update(uid=None):
	if uid is not None:
		mail = Mail.ldap_filter_by(uid=uid)[0]
	else:
		mail = Mail(uid=request.form.get('mail-uid'))
	mail.receivers = request.form.get('mail-receivers', '').splitlines()
	mail.destinations = request.form.get('mail-destinations', '').splitlines()
	ldap.session.add(mail)
	ldap.session.commit()
	flash('Mail mapping updated.')
	return redirect(url_for('mail.show', uid=mail.uid))

@bp.route("/<uid>/del")
@csrf_protect(blueprint=bp)
def delete(uid):
	mail = Mail.ldap_filter_by(uid=uid)[0]
	ldap.session.delete(mail)
	ldap.session.commit()
	flash('Deleted mail mapping.')
	return redirect(url_for('mail.index'))
